\name{EIA}
\alias{EIA}
\encoding{latin1}
\author{Cstor Guisande Gonzlez (Universidad de Vigo), Andrs Julin Rueda Quecho (Fundacin Natura), Fabian Rangel Silva (Fundacin Natura) and Jorge Mario Ros Vasquez (ISAGEN)}
\title{ENVIRONMENTAL IMPACT ASSESSMENT}
\description{An algorithm to evaluate statistically an Environmental Impact Assessment (EIA).}
\usage{
EIA(data, variables, period, before, after, site, date, VARSEDIG=FALSE,
minimum=FALSE, jpg=TRUE, removejpg=FALSE, p=0.05, cor=TRUE, ellipse=FALSE,
convex=TRUE, SCATTERPLOT=NULL, ROC=NULL, ROCTEST=NULL, PLOTOUTLIERS=NULL,
PLOTROC=NULL, ResetPAR=TRUE, PAR=NULL, XLAB=NULL, YLAB=NULL, XLIM=NULL,
YLIM=NULL, PCH=c(15,17,16), COLORD=rev(rainbow(2,alpha=0.4)), COLOR=NULL,
COLORC=NULL, LEGEND=NULL, MTEXT=NULL, TEXT=NULL, arrows=TRUE, larrow=1,
ARROWS=NULL, TEXTa=NULL, file1="Polar coordinates.csv",
file2="Outliers after.csv", na="NA", dec=",", row.names=FALSE)
}
\arguments{
  \item{data}{Data file.}
  \item{variables}{Variables to be analysed.}
  \item{period}{Variable with the categories of the periods. It must be two periods: the before and after the impact.}
  \item{before}{Name of the period before the impact.}
  \item{after}{Name of the period after the impact.}
  \item{site}{Variable with the name of the sampling sites.}
  \item{date}{Variable with the dates.}
  \item{VARSEDIG}{If it is TRUE, the variables are added for the estimation of polar coordinates in the priority order according to the method "overlap" (see details section of the function \link[VARSEDIG]{VARSEDIG}), and the variable is selected if it significantly contributes to discriminate between the before and after the environmental impact (EI).}
  \item{minimum}{If it is TRUE and the argument \emph{VARSEDIG=TRUE}, the algorithm is designed to find a significant discrimination between both groups with the minimum possible number of significant variables. Therefore, only the variables with higher discrimination capacity are selected. It is FALSE and the argument \emph{VARSEDIG=FALSE}, the algorithm selects all significant variables, and not only those with higher discrimination capacity.}
  \item{jpg}{It TRUE the scatterplots with the polar coordinates for each sampling time are exported to jpeg files.}
  \item{removejpg}{If TRUE all jpeg files are deleted from the folder.}
  \item{p}{Probability threshold of the Monte-Carlo test.}
  \item{cor}{If it is TRUE the variables are ordered according to the correlation between them when estimating the polar coordinates. Therefore, the next variable to another variable is the one that has a greater positive correlation. The first variable is the one with the higher discrimination capacity between the before and after the EI, that it is estimated with the method "overlap" (see details section of the function \link[VARSEDIG]{VARSEDIG}).}
  \item{ellipse}{If it is TRUE the ellipses with the levels of significance to the 0.5 (inner ellipse) and 0.95 (outer ellipse) of each category of the variable \emph{period} is depicted. These levels of significance can be modified by entering the function \link[car]{scatterplot} using the argument \emph{SCATTERPLOT} and modifying the argument \emph{levels=c(0.5,0.95)}.}
  \item{convex}{If it is TRUE the convex hull is depicted for each category.}
  \item{SCATTERPLOT}{It accesses the function \link[car]{scatterplot} of the car package of the graph \emph{biplot} with the polar coordinates.}
  \item{ROC}{It accesses the function \link[pROC]{roc} of the pROC package.}
  \item{ROCTEST}{It accesses the function \link[pROC]{roc.test} of the pROC package.}
  \item{PLOTOUTLIERS}{It allows to specify the characteristics of the function \link[graphics]{plot.default} of the plot with the outliers.}
  \item{PLOTROC}{It allows to specify the characteristics of the function \link[graphics]{plot.default} of the plot with the receiver operating characteristic curves (ROC curves).}
  \item{ResetPAR}{If it is FALSE, the default condition of the function PAR is not placed and maintained those defined by the user in previous graphics.}
  \item{PAR}{It accesses the function PAR that allows to modify many different aspects of the graph.}
  \item{XLAB}{Legend of the X axis in the scatterplot of the polar coordinates.}
  \item{YLAB}{Legend of the Y axis in the scatterplot of the polar coordinates.}
  \item{XLIM}{Vector with the limits of the X axis in the scatterplot of the polar coordinates.}
  \item{YLIM}{Vector with the limits of the Y axis in the scatterplot of the polar coordinates.}
  \item{PCH}{It allows to modify the symbols of the  scatterplot. It must be three symbols: the before and after the impact, and the outliers after the impact.}
  \item{COLORD}{It allows to modify the colours of the density plot. It must be two colours: the before and after the impact.}
  \item{COLOR}{It allows to modify the colours of the symbols in scatterplot. It must be three colours: the before and after the impact, and the outliers after the impact.}
  \item{COLORC}{It allows to modify the colours of the convex hull in the scatterplot. It must be two colours: the before and after the impact.}
  \item{LEGEND}{It allows to modify the legend in the scatterplot of the polar coordinates.}
  \item{MTEXT}{It allows to add text on the margins in the scatterplot of the polar coordinates.}
  \item{TEXT}{It allows to add text in any area of the inner part in the scatterplot of the polar coordinates.}
  \item{arrows}{If it is TRUE the arrows are shown in the scatterplot with the polar coordinates. These arrows show the vector of the variables selected when calculating the polar coordinates.}
  \item{larrow}{It modifies the length of the arrows.}
  \item{ARROWS}{It accesses the function \link[IDPmisc]{Arrows} of the package IDPmisc, which performs the arrows.}
  \item{TEXTa}{It allows to modify the labels at the end of the arrows.}
  \item{file1}{CSV FILES. Filename with the polar coordinates for all sampling times and sampling sites.}
  \item{file2}{CSV FILES. Filename with the outliers after the EIA.}
  \item{na}{CSV FILE. Text that is used in the cells without data.}
  \item{dec}{CSV FILE. It defines if the comma "," is used as decimal separator or the dot ".".}
  \item{row.names}{CSV FILE. Logical value that defines if identifiers are put in rows or a vector with a text for each of the rows.}
}
\value{It is obtained: 1) the CSV file with the polar coordinates for all sampling times and sampling sites; 2) the CSV file with the outliers after the EIA; 3) the plots with polar coordinates for each sampling period highlighting the outliers 4) the plot with the percentage of outliers after the impact for each sampling time and 5) a panel with 4 plots, two density plots with the overlap between the before and after the EI for both the polar coordinates X and Y, and the two ROC curves for also the polar coordinates X and Y.}
\details{
\strong{EIA Algorithm}

\strong{1. Polar coordinates}

All variables are transformed to a scale ranging between -1 and 1. For each sampling site and day the X and Y polar coordinates are estimated using the following equations:
\tabular{ll}{
\eqn{X=\displaystyle\sum_{i=1}^{n}|z_j|cos(\alpha)} \tab \eqn{Y=\displaystyle\sum_{i=1}^{n}|z_j|sin(\alpha)}
}
where \emph{z} is the value of the variable \emph{j} and \emph{n} the number of variables. 

Each variable is assigned an angle (\eqn{\alpha}). The increment value of the angle is always \eqn{\frac{360}{n*2}}. If for instance the number of variables is five, the increment angle is 36. Therefore, for the first variable if the value is \eqn{\geq0} the \eqn{\alpha} value is 36 and if the value is \eqn{<0} the value is 36+180, for the second variable if the value is \eqn{\geq0} the \eqn{\alpha} value is 36+36 and if the value is \eqn{<0} the value is 36+36+180, etc. Conversion of degrees to radians angle is carried out assuming that 1 degree = 0.0174532925 radians.

The order of the variables is consequently important, as a different alpha value is assigned. If the argument \emph{cor=TRUE}, this order is established by calculating the correlation matrix of the variables and by ordering them such that each variable is followed by the variable to which it is highly correlated. The goal is to favor a larger dispersion of data in the resulting polar coordinates system. The first variable is the one selected in the following step. If the argument \emph{cor=FALSE}, the order is established by the user when introducing variables.

\strong{2. Prioritizing variables by their capacity for discrimination}

If the argument \emph{cor=TRUE}, the overlap method described in the \link[VARSEDIG]{VARSEDIG}) algorithm (Guisande. 2016; Guisande et al., 2016) is used to prioritize the variables in accordance with their capacity for discrimination. A density curve is obtained for each variable and the overlap of the area under the curve between the before and after the EI is estimated for all variables. Those variables with lower overlap should have better discrimination capacities and, hence, all variables are ordered from lowest to highest overlap; from highest to lowest discrimination capacity.

\strong{3. Selection of those variables which discriminate significantly between the two periods}

If the argument \emph{VARSEDIG=TRUE}, the means of both the X and Y polar coordinates are estimated for the values obtained before and after the EI. Via these means the Euclidean distance is calculated between said periods.

The Monte-Carlo test is used to assess testing the statistical hypothesis if the value of one group is significantly higher or lower that the values of the other group. The test is performed for both the X and Y polar coordinates and compares all values in one group to those of the other group. For instance, when all values of group 1 are compared to those of group 2, and the mean X polar coordinate of group 1 is higher than the mean of group 2, the alternative hypothesis of the Monte-Carlo test is greater, and the p-value is estimated as (number of random values equal to or greater than that observed one + 1)/(number of permutations + 1). The null hypothesis is rejected if the p-value is less than the significance level. If the mean X polar coordinate of group 1 is lower than the mean of group 2 and the alternative hypothesis is smaller, the p-value is estimated as: number of random values equal to or less than that observed + 1/number of permutations + 1. Again, the null hypothesis is rejected if the p-value is lower than the significance level. The same process is applied when comparing all values from group 2 with those of group 1.

If the argument \emph{min=TRUE} and the argument \emph{VARSEDIG=TRUE}, a variable is selected if both of the following criteria are met: 1) they contribute to an increase in the Euclidean distance between both groups compared to the Euclidean distance obtained with the set of previously selected variables; and 2) the Monte-Carlo test p-values for the X and Y coordinates when comparing both group 1 to group 2 and group 2 to group 1 are smaller than the p-values obtained with the set of previous selected variables. Therefore, from the pool of all variables, only those variables with the highest significant contribution to discrimination between both periods are selected; that is, the minimum possible number of variables necessary for achievement of maximum discrimination between the periods.

If the argument \emph{minimum=FALSE} and the argument \emph{VARSEDIG=TRUE}, a variable is selected if it contributes to an increase the in Euclidean distance and the p-values are equal to, or less than, the p-values obtained with the set of previously selected variables. Therefore, all significant variables are selected from the pool of all variables, rather than solely from those with the highest discrimination capacity.

\strong{4. Identification of sampling sites for each sampling time after the EI, which are significantly different than before the EI}

A Monte-Carlo test is used to determine whether the X and/or Y polar coordinates obtained for each sampling time and site, after the EI, are significantly different than the mean X and Y polar coordinates of all values, obtained prior to the EI (hereinafter outliers). If the p value of the Monte-Carlo test is lower than 0.05 (this threshold probability may be modified by the user) for the X and/or Y polar coordinates, said site in the specified sampling period after the EI is considered to be an outlier. In other words, it is significantly different than the values obtained before the EI.

\strong{5. Testing whether the percentage of outliers increases following the EI}

Dickey & Fuller (1979) developed a procedure which enables testing of whether a variable has a unit root, or equivalently, the variable follows a random walk. There is an extension of the Dickey-Fuller test called the augmented Dickey-Fuller test (ADF), which removes all structural effects (autocorrelation) in the time series. This test was used to determine whether there was a significant increasing trend in the percentage of outliers after the EI.

\strong{6. Estimation of the Area Under the Curve of Receiver Operating Characteristic curves}

The Area Under the Curve (AUC) of Receiver Operating Characteristic curves (ROC curves) is a measure of how well two groups can be differentiated. The AUC of the two ROC curves, obtained both before and after the EI, were estimated, for both the X and Y polar coordinates, considering all sampling sites and times.

Finally, the AUC of the ROC curves (before and after the EI), obtained for both the X and Y polar coordinates, were compared to an AUC of 0.5 (the situation in which two distributions are equal). It can be assumed that, if the probability obtained in the comparison test is lower than 0.05 for the X and/or Y polar coordinates, the EI had a significant positive or negative impact on some of the variables analyzed.

\strong{FUNCTIONS}

The plot with the density curves is performed with the function \link[graphics]{plot.default} of base graphics package. The density curve is estimated with the function \link[stats]{density} of base stats package. The area under the curve is estimated with the function \link[kulife]{auc} of the package kulife (Ekstrom et al., 2015). The Monte-Carlo test was performed with the function \link[ade4]{as.randtest} of the package ade4 (Chessel et al., 2004; Dray et al., 2007; 2016). The arrows are depicted with the function \link[IDPmisc]{Arrows} of the package IDPmisc (Locher & Ruckstuhl, 2014). The scatterplot is performed with the function \link[car]{scatterplot} of the car package (Fox & Weisberg, 2011; Fox et al., 2014). The ROC curves are built with the function \link[pROC]{roc} and the function \link[pROC]{roc.test} is used to compare the AUC of the ROC curves, being both functions of the package pROC (Robin et al., 2017). The augmented Dickey-Fuller test was performed with the function \link[tseries]{adf.test} of package tseries (Trapletti & Hornik 2017). The convex hull is estimated with the function \link[grDevices]{chull} of the package grDevices.

\strong{EXAMPLES}

As a demonstration of the potential of the algorithm EIA, monthly climatic data (precipitation, wind speed, temperature, relative humidity, evaporation and solar radiation) were used from one station, and quarterly agronomic data (healthy cocoa pods, frosty pod rot \emph{Moniliophthora roreri}, black pod rot \emph{Phytophthora sp} and witch's broom \emph{Moniliophthora perniciosa}) ere taken from several sampling sites near the Sogamoso reservoir (Santander, COLOMBIA). This was carried out from January 2012 to June 2014 and from July 2014 to February 2017, before and after the reservoir was filled, respectively. Therefore, the EI was the filling up of the reservoir, and the goal was to evaluate potential changes in climatic and agronomic variables after, following this EI.

It is explained only the example 1, where climatic data and all variables are included in the analysis (argument \emph{VARSEDIG=FALSE}). The polar coordinates obtained the last month of this study shows that there were some months,  after the EI, which were statistically different than periods before the EI (Fig. 1). These outliers occurred due high temperatures, low precipitation, high wind speed and low humidity (Fig. 1).
\tabular{c}{
\strong{Figure 1.} Polar coordinates for all months before and after the reservoir was filled, and the\cr
months after the reservoir was filled significantly different (outliers) than values\cr
obtained before. Ellipses with the levels of significance of 0.5(inner ellipse)\cr
and 0.95 (outer ellipse) for each period.\cr
\figure{EIAF1}{options: width=3.7in}
}
\tabular{c}{
\strong{Figure 2. Left panels:} Density plots of the polar coordinates X (upper left panel) and Y (lower\cr
left panel) showed in Figure 1 for the periods before and after the reservoir was filled.\cr
\strong{Right panels:} Area Under the Curve (AUC) of Receiver Operating Characteristic curves\cr
(ROC curves) obtained for before and after the EI, for both polar coordinates X\cr
(upper right panel) and Y (lower right panel) showed in Figure 1.\cr
\figure{EIAF2}{options: width=3.9in}
}
\tabular{c}{
\strong{Figure 3.} Percentage of outliers for each month after the reservoir was filled.\cr
Probability is of the augmented Dickey-Fuller test (ADF).\cr
\figure{EIAF3}{options: width=2.9in}
}
The AUC of the ROC curve for polar coordinates X was 0.883, which is significantly different than an AUC of 0.5 (p < 0.001, Figure 2). In fact, the percentage of outliers increase after the reservoir was filled (Fig. 3). However, the probability of the augmented Dickey-Fuller test (ADF) was 0.559 (Fig. 3), and so the null hypothesis, that the time series was stationary, was accepted. It means that, although it seems that there is a trend toward a significant change in the climatic variables as a whole after the reservoir was filled -an increasing number of outliers (Fig. 3)- this trend is not significant yet. Therefore, a longer time series would be necessary in order to corroborate whether this change in climatic variables was due to the effect of filling the reservoir, or was natural induced.
}
\references{
Chessel, D. and Dufour, A.B. and Thioulouse, J. (2004) The ade4 package-I- One-table methods. \emph{R News}, 4, 5-10.

Dickey, D.A. & Fuller, W.A. (1979) Distribution of the estimators for autoregressive time series with a unit root. \emph{Journal of the American Statistical Association}, 74, 427-431. 

Dray, S. & Dufour, A.B. (2007) The ade4 package: implementing the duality diagram for ecologists. \emph{Journal of Statistical Software}, 22, 1-20.

Dray, S. & Dufour, A.B. and Chessel, D. (2007) The ade4 package-II: Two-table and K-table methods. \emph{R News}, 7(2), 47-52.

Dray , S., Dufour , A-B. & Thioulouse , J. (2016) Analysis of Ecological Data : Exploratory and Euclidean Methods in Environmental Sciences. R package version 1.7-5. Available at: \url{https://CRAN.R-project.org/package=ade4}.

Ekstrom, C., Skovgaard, Ib M. & Martinussen, T.(2015) Datasets and functions from the (now non-existing). R package version 0.1-14. Available at: \url{https://CRAN.R-project.org/package=kulife}.

Fox, J. & Weisberg, S. (2011) An R Companion to Applied Regression, Second Edition. Thousand Oaks CA: Sage. \url{ http://socserv.socsci.mcmaster.ca/jfox/Books/Companion}.

Fox, J., Weisberg, S., Adler, D., Bates, D., Baud-Bovy, G., Ellison, S., Firth, D., Friendly, M., Gorjanc, G., Graves, S., Heiberger, R., Laboissiere, R., Monette, G., Murdoch, D., Nilsson, H., Ogle, D., Ripley, B., Venables, W. & Zeileis, A. (2016) Companion to Applied Regression. R package version 2.1-4. Available at: \url{https://CRAN.R-project.org/package=car}.

Guisande, C. 2016. An algorithm for morphometric characters selection and statistical validation in morphological taxonomy. R package version 1.1. Available at: \url{https://CRAN.R-project.org/package=VARSEDIG}.

Guisande, C., Vari, R.P., Heine, J., Garca-Rosell, E., Gonzlez-Dacosta, J., Prez-Schofield, B.J., Gonzlez-Vilas, L. & Pelayo-Villamil, P. (2016) VARSEDIG: an algorithm for morphometric characters selection and statistical validation in morphological taxonomy. \emph{Zootaxa}, 4162, 571-580.

Locher, R. & Ruckstuhl, A. (2015) Utilities of Institute of Data Analyses and Process Design. R package version 1.1.17. Available at: \url{https://CRAN.R-project.org/package=IDPmisc}.

Robin, X., Turck, N., Hainard, A., Tiberti, N., Lisacek, F., Sanchez, J-C, Mller, M., Siegert, S. & DeLong, F. 2017. Display and Analyze ROC Curves. R package version 1.1.1. Available at: \url{https://CRAN.R-project.org/package=pROC}.

Trapletti, A & Hornik, K. (2017) tseries: Time Series Analysis and Computational Finance. R package version 0.10-38. Available at: \url{https://CRAN.R-project.org/package=tseries}.
}
\examples{

#Example 1: Atmospheric data

data(MALE)

EIA(data=MALE, variables=c("PR","WS","T","RH","EV","SR"), period="Period", before="Before",
after="After", site="Station", date="Date", jpg=FALSE, ellipse=TRUE,
convex=FALSE, ROCTEST=c("method='delong'"))

\dontrun{

#Example 2: As in example 1 but with convex

data(MALE)

EIA(data=MALE, variables=c("PR","WS","T","RH","EV","SR"), period="Period", before="Before",
after="After", site="Station", date="Date", jpg=FALSE, ROCTEST=c("method='delong'"))

#Example 3: Agronomic data

data(MAFitCC)

#With VARSEDIG FALSE
EIA(data=MAFitCC, variables=c("HC","FPR","BPR","WB"), period="Period", before="Before",
after="After", site="Patch", date="Date", removejpg=TRUE)

#With VARSEDIG TRUE
EIA(data=MAFitCC, variables=c("HC","FPR","BPR","WB"), period="Period", before="Before",
after="After", site="Patch", date="Date", VARSEDIG=TRUE)

}
}
\keyword{EIA}
